==> esper-6.0.1-sources.jar: com/espertech/esper/epl/approx/CountMinSketchAggAgentAdd.java <==
/*
 ***************************************************************************************
 *  Copyright (C) 2006 EsperTech, Inc. All rights reserved.                            *
 *  http://www.espertech.com/esper                                                     *
 *  http://www.espertech.com                                                           *
 *  ---------------------------------------------------------------------------------- *
 *  The software in this package is published under the terms of the GPL license       *
 *  a copy of which has been included with this distribution in the license.txt file.  *
 ***************************************************************************************
 */
package com.espertech.esper.epl.approx;

import com.espertech.esper.client.EventBean;
import com.espertech.esper.epl.agg.access.AggregationAgent;
import com.espertech.esper.epl.agg.access.AggregationState;
import com.espertech.esper.epl.expression.core.ExprEvaluator;
import com.espertech.esper.epl.expression.core.ExprEvaluatorContext;

public class CountMinSketchAggAgentAdd implements AggregationAgent {

    private final ExprEvaluator stringEvaluator;

    public CountMinSketchAggAgentAdd(ExprEvaluator stringEvaluator) {
        this.stringEvaluator = stringEvaluator;
    }

    public void applyEnter(EventBean[] eventsPerStream, ExprEvaluatorContext exprEvaluatorContext, AggregationState aggregationState) {
        Object value = stringEvaluator.evaluate(eventsPerStream, true, exprEvaluatorContext);
        CountMinSketchAggState state = (CountMinSketchAggState) aggregationState;
        state.add(value);
    }

    public void applyLeave(EventBean[] eventsPerStream, ExprEvaluatorContext exprEvaluatorContext, AggregationState aggregationState) {

    }
}

==> esper-7.1.0-sources.jar: com/espertech/esper/epl/approx/CountMinSketchAggAgentAdd.java <==
/*
 ***************************************************************************************
 *  Copyright (C) 2006 EsperTech, Inc. All rights reserved.                            *
 *  http://www.espertech.com/esper                                                     *
 *  http://www.espertech.com                                                           *
 *  ---------------------------------------------------------------------------------- *
 *  The software in this package is published under the terms of the GPL license       *
 *  a copy of which has been included with this distribution in the license.txt file.  *
 ***************************************************************************************
 */
package com.espertech.esper.epl.approx;

import com.espertech.esper.client.EventBean;
import com.espertech.esper.epl.agg.access.AggregationAgent;
import com.espertech.esper.epl.agg.access.AggregationState;
import com.espertech.esper.epl.expression.core.ExprEvaluator;
import com.espertech.esper.epl.expression.core.ExprEvaluatorContext;

public class CountMinSketchAggAgentAdd implements AggregationAgent {

    protected final ExprEvaluator stringEvaluator;

    public CountMinSketchAggAgentAdd(ExprEvaluator stringEvaluator) {
        this.stringEvaluator = stringEvaluator;
    }

    public void applyEnter(EventBean[] eventsPerStream, ExprEvaluatorContext exprEvaluatorContext, AggregationState aggregationState) {
        Object value = stringEvaluator.evaluate(eventsPerStream, true, exprEvaluatorContext);
        CountMinSketchAggState state = (CountMinSketchAggState) aggregationState;
        state.add(value);
    }

    public void applyLeave(EventBean[] eventsPerStream, ExprEvaluatorContext exprEvaluatorContext, AggregationState aggregationState) {

    }
}
